==> huaweicloudsdkdns-3.0.52-py2.py3-none-any.whl: huaweicloudsdkdns/v2/model/version_item.py <==
# coding: utf-8

import re
import six





class VersionItem:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'status': 'str',
        'links': 'list[LinksItem]',
        'updated': 'str',
        'version': 'str',
        'min_version': 'str'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'links': 'links',
        'updated': 'updated',
        'version': 'version',
        'min_version': 'min_version'
    }

    def __init__(self, id=None, status=None, links=None, updated=None, version=None, min_version=None):
        """VersionItem - a model defined in huaweicloud sdk"""
        
        

        self._id = None
        self._status = None
        self._links = None
        self._updated = None
        self._version = None
        self._min_version = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        if links is not None:
            self.links = links
        if updated is not None:
            self.updated = updated
        if version is not None:
            self.version = version
        if min_version is not None:
            self.min_version = min_version

    @property
    def id(self):
        """Gets the id of this VersionItem.

        版本ID（版本号），如v2。

        :return: The id of this VersionItem.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VersionItem.

        版本ID（版本号），如v2。

        :param id: The id of this VersionItem.
        :type: str
        """
        self._id = id

    @property
    def status(self):
        """Gets the status of this VersionItem.

        版本状态，为如下3种： CURRENT：表示该版本为主推版本。 SUPPORTED：表示为老版本，但是现在还继续支持。 DEPRECATED：表示为废弃版本，存在后续删除的可能。

        :return: The status of this VersionItem.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this VersionItem.

        版本状态，为如下3种： CURRENT：表示该版本为主推版本。 SUPPORTED：表示为老版本，但是现在还继续支持。 DEPRECATED：表示为废弃版本，存在后续删除的可能。

        :param status: The status of this VersionItem.
        :type: str
        """
        self._status = status

    @property
    def links(self):
        """Gets the links of this VersionItem.

        API的URL地址。

        :return: The links of this VersionItem.
        :rtype: list[LinksItem]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this VersionItem.

        API的URL地址。

        :param links: The links of this VersionItem.
        :type: list[LinksItem]
        """
        self._links = links

    @property
    def updated(self):
        """Gets the updated of this VersionItem.

        版本发布时间。

        :return: The updated of this VersionItem.
        :rtype: str
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this VersionItem.

        版本发布时间。

        :param updated: The updated of this VersionItem.
        :type: str
        """
        self._updated = updated

    @property
    def version(self):
        """Gets the version of this VersionItem.

        支持的最大微版本号。若该版本API不支持微版本，则为空。

        :return: The version of this VersionItem.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this VersionItem.

        支持的最大微版本号。若该版本API不支持微版本，则为空。

        :param version: The version of this VersionItem.
        :type: str
        """
        self._version = version

    @property
    def min_version(self):
        """Gets the min_version of this VersionItem.

        支持的最小微版本号。若该版本API不支持微版本，则为空。

        :return: The min_version of this VersionItem.
        :rtype: str
        """
        return self._min_version

    @min_version.setter
    def min_version(self, min_version):
        """Sets the min_version of this VersionItem.

        支持的最小微版本号。若该版本API不支持微版本，则为空。

        :param min_version: The min_version of this VersionItem.
        :type: str
        """
        self._min_version = min_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VersionItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdns-3.0.53-py2.py3-none-any.whl: huaweicloudsdkdns/v2/model/version_item.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class VersionItem:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'status': 'str',
        'links': 'list[LinksItem]',
        'updated': 'str',
        'version': 'str',
        'min_version': 'str'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'links': 'links',
        'updated': 'updated',
        'version': 'version',
        'min_version': 'min_version'
    }

    def __init__(self, id=None, status=None, links=None, updated=None, version=None, min_version=None):
        """VersionItem - a model defined in huaweicloud sdk"""
        
        

        self._id = None
        self._status = None
        self._links = None
        self._updated = None
        self._version = None
        self._min_version = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        if links is not None:
            self.links = links
        if updated is not None:
            self.updated = updated
        if version is not None:
            self.version = version
        if min_version is not None:
            self.min_version = min_version

    @property
    def id(self):
        """Gets the id of this VersionItem.

        版本ID（版本号），如v2。

        :return: The id of this VersionItem.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VersionItem.

        版本ID（版本号），如v2。

        :param id: The id of this VersionItem.
        :type: str
        """
        self._id = id

    @property
    def status(self):
        """Gets the status of this VersionItem.

        版本状态，为如下3种： CURRENT：表示该版本为主推版本。 SUPPORTED：表示为老版本，但是现在还继续支持。 DEPRECATED：表示为废弃版本，存在后续删除的可能。

        :return: The status of this VersionItem.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this VersionItem.

        版本状态，为如下3种： CURRENT：表示该版本为主推版本。 SUPPORTED：表示为老版本，但是现在还继续支持。 DEPRECATED：表示为废弃版本，存在后续删除的可能。

        :param status: The status of this VersionItem.
        :type: str
        """
        self._status = status

    @property
    def links(self):
        """Gets the links of this VersionItem.

        API的URL地址。

        :return: The links of this VersionItem.
        :rtype: list[LinksItem]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this VersionItem.

        API的URL地址。

        :param links: The links of this VersionItem.
        :type: list[LinksItem]
        """
        self._links = links

    @property
    def updated(self):
        """Gets the updated of this VersionItem.

        版本发布时间。

        :return: The updated of this VersionItem.
        :rtype: str
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this VersionItem.

        版本发布时间。

        :param updated: The updated of this VersionItem.
        :type: str
        """
        self._updated = updated

    @property
    def version(self):
        """Gets the version of this VersionItem.

        支持的最大微版本号。若该版本API不支持微版本，则为空。

        :return: The version of this VersionItem.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this VersionItem.

        支持的最大微版本号。若该版本API不支持微版本，则为空。

        :param version: The version of this VersionItem.
        :type: str
        """
        self._version = version

    @property
    def min_version(self):
        """Gets the min_version of this VersionItem.

        支持的最小微版本号。若该版本API不支持微版本，则为空。

        :return: The min_version of this VersionItem.
        :rtype: str
        """
        return self._min_version

    @min_version.setter
    def min_version(self, min_version):
        """Sets the min_version of this VersionItem.

        支持的最小微版本号。若该版本API不支持微版本，则为空。

        :param min_version: The min_version of this VersionItem.
        :type: str
        """
        self._min_version = min_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VersionItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
